package javax.rtgedition;

/***********************************************
 *  RTG, University of Pennsylvania
  * Author:	Dave Arney	11/07/01
  *                    Woongsup Kim
  **********************************************/
import java.util.*;


public abstract class HighResolutionTime {

  /* This is to ensure that you don't leave out a 0 by
   * accident!
  */
  protected static final int NANOS_TO_MILLIS = 1000000;
    
  protected long millis;
  protected int nanos;
  
  
  public abstract AbsoluteTime absolute(Clock clock, AbsoluteTime dest);

/* compareTo compares time to this. If this is greater, compareTo returns 1,
 * if they are equal, it returns 0 and if time is greater than this, it returns -1
*/
  public int compareTo(HighResolutionTime time){
      int result = 0;
      if (millis > time.millis)
         result = 1;
      else if (millis == time.millis) {
         if (nanos > time.nanos)
	    result = 1;
	 else if (nanos == time.nanos )
	    result = 0;
	 else if (nanos < time.nanos)
	    result = -1;
      }
  return result;
  }

  /* for the Comparable interface */
  public int compareTo(java.lang.Object object) 
  {
      if( object instanceof HighResolutionTime )
      {
          return compareTo((HighResolutionTime) object);
      }
      else
      {
          throw new ClassCastException();
      }
   }

  public boolean equals(HighResolutionTime time)
  {
      return (time.millis == this.millis && time.nanos == this.nanos);
  }

  public boolean equals(java.lang.Object object){
        if(object instanceof HighResolutionTime )
            return equals((HighResolutionTime) object);
        else
            return object == this;
  }

  public final long getMilliseconds()
  {
      return millis;
  }

  public final int getNanoseconds()
  {
      return nanos;
  }

  /* This looks odd, it's from wokim -DA */
  public int hashCode(){
  	long h;

	h = millis * 31 + (long)nanos;
	h = h & 63;
  	return (int)h;
  }

  public void set(HighResolutionTime time)
  {
      millis = time.millis;
      nanos = time.nanos;
  }

  public void set(long millis)
  {
      this.millis = millis;
      this.nanos = 0;
  }

  /*
   * Must make sure we keep canonical time.
   */
  
  public void set(long millis, int nanos)
  {
      this.millis = millis + nanos/NANOS_TO_MILLIS;
      this.nanos = nanos%NANOS_TO_MILLIS;
  }
} 
