/*
 * RelativeTime.java
 *
 * Created on November 9, 2001, 9:43 PM
 */

package javax.rtgedition;

/**
 * Real Time Edition - Keeps things in Canonical Time
 * @author  vsabella
 * @version 1.0.0
 */
public class RelativeTime extends javax.rtgedition.HighResolutionTime {

    /** Creates new RelativeTime */
    
    public RelativeTime() {
        this(0,0);
    }
    
    public RelativeTime(long millis, int nanos)
    {
        /* Make sure we keep canonical time. */ 
        this.millis  = millis + nanos/NANOS_TO_MILLIS;
        this.nanos   = nanos%NANOS_TO_MILLIS;
    }
    
    public RelativeTime(RelativeTime time)
    {
        this.millis = time.millis;
        this.nanos  = time.nanos;
    }
    
    public AbsoluteTime absolute(Clock clock, AbsoluteTime destination)
    {
        if(destination == null)
        {
            destination = new AbsoluteTime();
        }
        
        /*
         * Note destination.set(long,int) comes from HighResolutionTime.java
         * and is pre-compensated for canonical time.
         */
        
        clock.getTime(destination);
        destination.set(destination.millis+this.millis,destination.nanos+this.nanos);
        return destination;
    }
    
    public RelativeTime add(long millis, int nanos)
    {
        return new RelativeTime(this.millis+millis, this.nanos+nanos);
    }
    
    public RelativeTime add(long millis, int nanos, RelativeTime destination)
    {
        if(destination == null)
        {
            return new RelativeTime(this.millis+millis,this.nanos+nanos);
        }
      
        /* 
         * @see add(long millis, int nanos);  
         * set() is canonical time compensated
        */
        
        destination.set(this.millis+millis,this.nanos+nanos);
        return destination;
    }
    
    public final RelativeTime add(RelativeTime time)
    {
        /*
         * Don't trust the compiler to inline the add()
         * method so we'll just do it again.
         */
        
        return new RelativeTime(this.millis+time.millis,this.nanos+time.nanos);
    }
    
    public final RelativeTime add(RelativeTime time, RelativeTime destination)
    {
        if(destination == null)
        {
            /*
             * I return right away to save an extra method call and give slightly
             * better performance.  :-)   - vjs Nov 10, 2001
             */
            return new RelativeTime(this.millis+time.millis,this.nanos+time.nanos);
        }
        
        destination.set(this.millis+time.millis,this.nanos+time.nanos);
        return destination;
    }
    
    public void addInterarrivalTo(AbsoluteTime destination)
    {
        // (Note can't divide by the frequency since the frequency is one! :-)
        destination.add(this,destination);
    }
    
    public RelativeTime getInterarrivalTime(RelativeTime destination)
    {
        destination.set(this);
        return this;
    }
    
    public final RelativeTime subtract(RelativeTime time)
    {
        int nanos = this.nanos-time.nanos;
        long millis = this.millis - time.millis;
        
        if(nanos < 0)
        {
            millis -= 1;
            nanos  += NANOS_TO_MILLIS;
        }
        
        return new RelativeTime(millis,nanos);
    }
    
    public RelativeTime subtract(RelativeTime time, RelativeTime destination)
    {
        if(destination == null)
        {
            destination = new RelativeTime();
        }

        int nanos = this.nanos-time.nanos;
        long millis = this.millis - time.millis;
        
        if(nanos < 0)
        {
            millis -= 1;
            nanos  += NANOS_TO_MILLIS;
        }
        
        destination.set(millis,nanos);
        return destination;
    }
    
    public java.lang.String toString()
    {
        return this.millis+"ms "+this.nanos+"ns";
    }
    
}
